@@ -16,27 +16,17 @@ using namespace CalendarSupport;
 inline QString &quote(QString &string)
 {
     Q_ASSERT(CategoryConfig::categorySeparator != QLatin1String("@"));
-    return string.replace(QLatin1Char('@'), QStringLiteral("@0")).replace(QLatin1Char(
-                                                                              '\\')
-                                                                          +CategoryConfig::categorySeparator,
-                                                                          QStringLiteral("@1"));
+    return string.replace(QLatin1Char('@'), QStringLiteral("@0")).replace(QLatin1Char('\\') + CategoryConfig::categorySeparator, QStringLiteral("@1"));
 }
 
 inline QStringList &unquote(QStringList &strings)
 {
-    return
-        strings.replaceInStrings(QStringLiteral("@1"), CategoryConfig::categorySeparator).
-        replaceInStrings(QStringLiteral("@0"), QStringLiteral("@"));
+    return strings.replaceInStrings(QStringLiteral("@1"), CategoryConfig::categorySeparator).replaceInStrings(QStringLiteral("@0"), QStringLiteral("@"));
 }
 
 QStringList CategoryHierarchyReader::path(QString string)
 {
-    QStringList _path
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        = quote(string).split(CategoryConfig::categorySeparator, QString::SkipEmptyParts);
-#else
-        = quote(string).split(CategoryConfig::categorySeparator, Qt::SkipEmptyParts);
-#endif
+    QStringList _path = quote(string).split(CategoryConfig::categorySeparator, Qt::SkipEmptyParts);
     return unquote(_path);
 }
 
@@ -58,8 +48,7 @@ void CategoryHierarchyReader::read(const QStringList &categories)
         QStringList::Iterator jt, kt;
         int split_level = 0;
         QStringList new_path = _path; // save it for later
-        for (jt = _path.begin(), kt = last_path.begin();
-             jt != _path.end() && kt != last_path.end(); ++jt, ++kt) {
+        for (jt = _path.begin(), kt = last_path.begin(); jt != _path.end() && kt != last_path.end(); ++jt, ++kt) {
             if (*jt == *kt) {
                 split_level++;
             } else {
@@ -131,7 +120,7 @@ void CategoryHierarchyReaderQTreeWidget::goUp()
 
 void CategoryHierarchyReaderQTreeWidget::addChild(const QString &label, const QVariant &userData)
 {
-    Q_UNUSED(userData);
+    Q_UNUSED(userData)
 
     if (mItem) {
         mItem = new QTreeWidgetItem(mItem, QStringList() << label);
