@@ -1,46 +1,29 @@
 /*
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2004 David Faure <faure@kde.org>
-  Copyright (C) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
+  SPDX-FileCopyrightText: 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "eventarchiver.h"
 
 #include "kcalprefs.h"
 #include "utils.h"
-#include <kio_version.h>
 #include <Akonadi/Calendar/IncidenceChanger>
 
-#include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/FileStorage>
+#include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/MemoryCalendar>
 
 #include <KCalUtils/Stringify>
 
 #include "calendarsupport_debug.h"
-#include <KLocalizedString>
-#include <KMessageBox>
 #include <KIO/FileCopyJob>
 #include <KIO/StatJob>
 #include <KJobWidgets>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 #include <QLocale>
 #include <QTemporaryFile>
@@ -53,7 +36,8 @@ using namespace CalendarSupport;
 class GroupwareScoppedDisabler
 {
 public:
-    GroupwareScoppedDisabler(Akonadi::IncidenceChanger *changer) : m_changer(changer)
+    GroupwareScoppedDisabler(Akonadi::IncidenceChanger *changer)
+        : m_changer(changer)
     {
         m_wasEnabled = m_changer->groupwareCommunication();
         m_changer->setGroupwareCommunication(false);
@@ -64,8 +48,8 @@ public:
         m_changer->setGroupwareCommunication(m_wasEnabled);
     }
 
-    bool m_wasEnabled;
-    Akonadi::IncidenceChanger *m_changer = nullptr;
+    bool m_wasEnabled = false;
+    Akonadi::IncidenceChanger *const m_changer;
 };
 
 EventArchiver::EventArchiver(QObject *parent)
@@ -102,7 +86,12 @@ void EventArchiver::runAuto(const Akonadi::ETMCalendar::Ptr &calendar, Akonadi::
     run(calendar, changer, limitDate, widget, withGUI, false);
 }
 
-void EventArchiver::run(const Akonadi::ETMCalendar::Ptr &calendar, Akonadi::IncidenceChanger *changer, const QDate &limitDate, QWidget *widget, bool withGUI, bool errorIfNone)
+void EventArchiver::run(const Akonadi::ETMCalendar::Ptr &calendar,
+                        Akonadi::IncidenceChanger *changer,
+                        const QDate &limitDate,
+                        QWidget *widget,
+                        bool withGUI,
+                        bool errorIfNone)
 {
     GroupwareScoppedDisabler disabler(changer); // Disables groupware communication temporarily
 
@@ -112,12 +101,11 @@ void EventArchiver::run(const Akonadi::ETMCalendar::Ptr &calendar, Akonadi::Inci
     KCalendarCore::Journal::List journals;
 
     if (KCalPrefs::instance()->mArchiveEvents) {
-        events = calendar->rawEvents(
-            QDate(1769, 12, 1),
-            // #29555, also advertised by the "limitDate not included" in the class docu
-            limitDate.addDays(-1),
-            QTimeZone::systemTimeZone(),
-            true);
+        events = calendar->rawEvents(QDate(1769, 12, 1),
+                                     // #29555, also advertised by the "limitDate not included" in the class docu
+                                     limitDate.addDays(-1),
+                                     QTimeZone::systemTimeZone(),
+                                     true);
     }
     if (KCalPrefs::instance()->mArchiveTodos) {
         const KCalendarCore::Todo::List rawTodos = calendar->rawTodos();
@@ -130,17 +118,13 @@ void EventArchiver::run(const Akonadi::ETMCalendar::Ptr &calendar, Akonadi::Inci
         }
     }
 
-    const KCalendarCore::Incidence::List incidences = calendar->mergeIncidenceList(events, todos,
-                                                                                   journals);
+    const KCalendarCore::Incidence::List incidences = calendar->mergeIncidenceList(events, todos, journals);
 
-    qCDebug(CALENDARSUPPORT_LOG) << "archiving incidences before" << limitDate
-                                 << " ->" << incidences.count() << " incidences found.";
+    qCDebug(CALENDARSUPPORT_LOG) << "archiving incidences before" << limitDate << " ->" << incidences.count() << " incidences found.";
     if (incidences.isEmpty()) {
         if (withGUI && errorIfNone) {
             KMessageBox::information(widget,
-                                     i18n("There are no items before %1",
-                                          QLocale::system().toString(limitDate,
-                                                                     QLocale::ShortFormat)),
+                                     i18n("There are no items before %1", QLocale::system().toString(limitDate, QLocale::ShortFormat)),
                                      QStringLiteral("ArchiverNoIncidences"));
         }
         return;
@@ -156,7 +140,11 @@ void EventArchiver::run(const Akonadi::ETMCalendar::Ptr &calendar, Akonadi::Inci
     }
 }
 
-void EventArchiver::deleteIncidences(Akonadi::IncidenceChanger *changer, const QDate &limitDate, QWidget *widget, const Akonadi::Item::List &items, bool withGUI)
+void EventArchiver::deleteIncidences(Akonadi::IncidenceChanger *changer,
+                                     const QDate &limitDate,
+                                     QWidget *widget,
+                                     const Akonadi::Item::List &items,
+                                     bool withGUI)
 {
     QStringList incidenceStrs;
     Akonadi::Item::List::ConstIterator it;
@@ -167,28 +155,33 @@ void EventArchiver::deleteIncidences(Akonadi::IncidenceChanger *changer, const Q
     }
 
     if (withGUI) {
-        const int result = KMessageBox::warningContinueCancelList(
-            widget,
-            i18n("Delete all items before %1 without saving?\n"
-                 "The following items will be deleted:",
-                 QLocale::system().toString(limitDate, QLocale::ShortFormat)),
-            incidenceStrs,
-            i18n("Delete Old Items"), KStandardGuiItem::del());
+        const int result = KMessageBox::warningContinueCancelList(widget,
+                                                                  i18n("Delete all items before %1 without saving?\n"
+                                                                       "The following items will be deleted:",
+                                                                       QLocale::system().toString(limitDate, QLocale::ShortFormat)),
+                                                                  incidenceStrs,
+                                                                  i18n("Delete Old Items"),
+                                                                  KStandardGuiItem::del());
         if (result != KMessageBox::Continue) {
             return;
         }
     }
 
-    changer->deleteIncidences(items, /**parent=*/ widget);
+    changer->deleteIncidences(items, /**parent=*/widget);
 
     // TODO: Q_EMIT only after hearing back from incidence changer
     Q_EMIT eventsDeleted();
 }
 
-void EventArchiver::archiveIncidences(const Akonadi::ETMCalendar::Ptr &calendar, Akonadi::IncidenceChanger *changer, const QDate &limitDate, QWidget *widget, const KCalendarCore::Incidence::List &incidences, bool withGUI)
+void EventArchiver::archiveIncidences(const Akonadi::ETMCalendar::Ptr &calendar,
+                                      Akonadi::IncidenceChanger *changer,
+                                      const QDate &limitDate,
+                                      QWidget *widget,
+                                      const KCalendarCore::Incidence::List &incidences,
+                                      bool withGUI)
 {
-    Q_UNUSED(limitDate);
-    Q_UNUSED(withGUI);
+    Q_UNUSED(limitDate)
+    Q_UNUSED(withGUI)
 
     FileStorage storage(calendar);
 
@@ -214,7 +207,7 @@ void EventArchiver::archiveIncidences(const Akonadi::ETMCalendar::Ptr &calendar,
 
     FileStorage archiveStore(archiveCalendar);
     archiveStore.setFileName(tmpFileName);
-    ICalFormat *format = new ICalFormat();
+    auto format = new ICalFormat();
     archiveStore.setSaveFormat(format);
     if (!archiveStore.load()) {
         qCDebug(CALENDARSUPPORT_LOG) << "Can't load calendar from temp file";
@@ -245,11 +238,7 @@ void EventArchiver::archiveIncidences(const Akonadi::ETMCalendar::Ptr &calendar,
     if (archiveURL.isLocalFile()) {
         fileExists = QFile::exists(archiveURL.toLocalFile());
     } else {
-#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
-        auto job = KIO::stat(archiveURL, KIO::StatJob::SourceSide, 0);
-#else
         auto job = KIO::statDetails(archiveURL, KIO::StatJob::SourceSide, KIO::StatBasic);
-#endif
 
         KJobWidgets::setWindow(job, widget);
         fileExists = job->exec();
@@ -283,8 +272,7 @@ void EventArchiver::archiveIncidences(const Akonadi::ETMCalendar::Ptr &calendar,
         } else {
             errmess = i18nc("save failure cause unknown", "Reason unknown");
         }
-        KMessageBox::error(widget, i18n("Cannot write archive file %1. %2",
-                                        archiveStore.fileName(), errmess));
+        KMessageBox::error(widget, i18n("Cannot write archive file %1. %2", archiveStore.fileName(), errmess));
         QFile::remove(tmpFileName);
         return;
     }
