@@ -17,7 +17,8 @@
 
 class ItemPrivateData;
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 /**
  * The FreeBusyItemModel is a 2-level tree structure.
  *
@@ -30,11 +31,7 @@ class CALENDARSUPPORT_EXPORT FreeBusyItemModel : public QAbstractItemModel
 {
     Q_OBJECT
 public:
-    enum Roles {
-        AttendeeRole = Qt::UserRole,
-        FreeBusyRole,
-        FreeBusyPeriodRole
-    };
+    enum Roles { AttendeeRole = Qt::UserRole, FreeBusyRole, FreeBusyPeriodRole };
 
     explicit FreeBusyItemModel(QObject *parent = nullptr);
     ~FreeBusyItemModel() override;
